Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(433)

Unified Diff: components/mus/ws/access_policy.h

Issue 1406153004: components/mus/public/interfaces View => Window (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Yet another rebase Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/mus/public/interfaces/window_tree_host.mojom ('k') | components/mus/ws/client_connection.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/mus/ws/access_policy.h
diff --git a/components/mus/ws/access_policy.h b/components/mus/ws/access_policy.h
index cfc118fd511bdba53bb584b77df110f04bb34e1a..175e1c8d37d8db0cc50b1edc065f84cb42066b3f 100644
--- a/components/mus/ws/access_policy.h
+++ b/components/mus/ws/access_policy.h
@@ -19,16 +19,16 @@ class AccessPolicy {
virtual ~AccessPolicy() {}
// Unless otherwise mentioned all arguments have been validated. That is the
// |view| arguments are non-null unless otherwise stated (eg CanSetView() is
// allowed to take a NULL view).
- virtual bool CanRemoveViewFromParent(const ServerView* view) const = 0;
- virtual bool CanAddView(const ServerView* parent,
- const ServerView* child) const = 0;
- virtual bool CanReorderView(const ServerView* view,
- const ServerView* relative_view,
- mojo::OrderDirection direction) const = 0;
- virtual bool CanDeleteView(const ServerView* view) const = 0;
- virtual bool CanGetViewTree(const ServerView* view) const = 0;
+ virtual bool CanRemoveWindowFromParent(const ServerView* view) const = 0;
+ virtual bool CanAddWindow(const ServerView* parent,
+ const ServerView* child) const = 0;
+ virtual bool CanReorderWindow(const ServerView* view,
+ const ServerView* relative_view,
+ mojom::OrderDirection direction) const = 0;
+ virtual bool CanDeleteWindow(const ServerView* view) const = 0;
+ virtual bool CanGetWindowTree(const ServerView* view) const = 0;
// Used when building a view tree (GetViewTree()) to decide if we should
// descend into |view|.
virtual bool CanDescendIntoViewForViewTree(const ServerView* view) const = 0;
@@ -36,9 +36,9 @@ class AccessPolicy {
uint32_t policy_bitmask) const = 0;
virtual bool CanChangeViewVisibility(const ServerView* view) const = 0;
virtual bool CanSetWindowSurfaceId(const ServerView* view) const = 0;
- virtual bool CanSetViewBounds(const ServerView* view) const = 0;
- virtual bool CanSetViewProperties(const ServerView* view) const = 0;
- virtual bool CanSetViewTextInputState(const ServerView* view) const = 0;
+ virtual bool CanSetWindowBounds(const ServerView* view) const = 0;
+ virtual bool CanSetWindowProperties(const ServerView* view) const = 0;
+ virtual bool CanSetWindowTextInputState(const ServerView* view) const = 0;
virtual bool CanSetFocus(const ServerView* view) const = 0;
virtual bool CanSetClientArea(const ServerView* window) const = 0;
« no previous file with comments | « components/mus/public/interfaces/window_tree_host.mojom ('k') | components/mus/ws/client_connection.h » ('j') | no next file with comments »
@@ -19,16 +19,16 @@ class AccessPolicy {
virtual ~AccessPolicy() {}
// Unless otherwise mentioned all arguments have been validated. That is the
- // |view| arguments are non-null unless otherwise stated (eg CanSetView() is
+ // |view| arguments are non-null unless otherwise stated (eg CanSetWindow() is
// allowed to take a NULL view).

Powered by Google App Engine
This is Rietveld 408576698